==> cms-db_v0.7.9.tar.gz: admin/urlindex.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

/* Load the characters to replace */

global $replace_pairs;
$replace_pairs = array( '_' => '-');
$handle = opendir('./specialchars/');
while (false !== ($file = readdir($handle))) {
	if(is_file('./specialchars/'.$file)) {
		$list = file_get_contents('./specialchars/'.$file);
		$list = explode("\n", $list);
		foreach ($list as $line) {
			if ($line != '' && substr($line, 0, 1) != '#') {
				$line = explode("\t", $line);
				if (strpos($line[0], ';') !== false) {
					$chars = explode(';', $line[0]);
					foreach ($chars as $char) {
						$replace_pairs[$char] = $line[1];
					}
				} else {
					$replace_pairs[$line[0]] = $line[1];
				}
			}
		}
	}
}
closedir($handle);

function _urlindex_get_pages($folder = '') {
	if (!isset($pages)) {
		static $pages = array();
	}
	$dir = '../data/pages/'.$folder;
	$handle = opendir($dir);
	while (false !== ($file = readdir($handle))) {
		if($file != "." && $file != "..") {
			if(is_dir($dir.'/'.$file)) {
				_urlindex_get_pages($folder.'/'.$file);
			} else {
				$pages[] = $folder.'/'.$file;
			}
		}
	}
	closedir($handle);
	return $pages;
}

function _urlindex_get_url($page, $urls) {
	global $replace_pairs;
	$split = explode('/', $page);
	$count = count($split);
	$url = $split[$count-2];
	$url = substr($url, 3);
	$url = str_replace(array('.DEL', 'SLASH', 'AND'), array('', '-', '-'), $url);
	$url = strtolower($url);
	$url = strtr($url, $replace_pairs);
	# This doesn't work if the server has problems with unicode
	# $url = preg_replace('/[^\w-]/', '', $url);
	$url = preg_replace('/[^A-Za-z0-9-]/', '', $url);
	$url = preg_replace('/-+/', '-', $url);
	if (in_array($url, $urls) or ($url == '' && in_array('1', $urls))) {
		$i = 2;
		if ($url != '') {
			$before = $url.'-';
		} else {
			$before = '';
		}
		while (in_array($before.$i, $urls)) {
			$i++;
		}
		$url = $before.$i;
	} elseif ($url == '') {
		$url = '1';
	}
	return $url;
}

function generate_urlindex() {
	$pages = _urlindex_get_pages();
	natcasesort($pages);
	$urls = array();
	$urlindex = '';
	foreach($pages as $page) {
		$contents = file_get_contents('../data/pages/'.$page);
		if (preg_match('/%%REDIRECT-(.*)%%/U', $contents, $matches) == 0) {
			$url = _urlindex_get_url($page, $urls);
			$urls[] = $url;
			$urlindex .= $url."\t".$page."\n";
		} else {
			$urlindex .= 'REDIRECT:'.$matches[1]."\t".$page."\n";
		}
	}
	$handle = fopen('../data/urlindex.txt', 'w+');
	fwrite($handle, $urlindex."\n");
	fclose($handle);
}
?>

==> cms-db_v0.8.1.tar.gz: admin/urlindex.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	include('friendlyerror.firewall.inc.php');
	die();
}

include('../data/settings/url.inc.php');

/* Load the characters to replace */
global $replace_pairs;
$replace_pairs = array( '_' => '-');
$handle = opendir('./specialchars/');
while (false !== ($file = readdir($handle))) {
	if(is_file('./specialchars/'.$file)) {
		$list = file_get_contents('./specialchars/'.$file);
		$list = explode("\n", $list);
		foreach ($list as $line) {
			if ($line != '' && substr($line, 0, 1) != '#') {
				$line = explode("\t", $line);
				if (strpos($line[0], ';') !== false) {
					$chars = explode(';', $line[0]);
					foreach ($chars as $char) {
						$replace_pairs[$char] = $line[1];
					}
				} else {
					$replace_pairs[$line[0]] = $line[1];
				}
			}
		}
	}
}
closedir($handle);

function _urlindex_get_pages($folder = '') {
	if (!isset($pages)) {
		static $pages = array();
	}
	$dir = '../data/pages/'.$folder;
	$handle = opendir($dir);
	while (false !== ($file = readdir($handle))) {
		if($file != "." && $file != "..") {
			if(is_dir($dir.'/'.$file)) {
				_urlindex_get_pages($folder.'/'.$file);
			} else {
				$pages[] = $folder.'/'.$file;
			}
		}
	}
	closedir($handle);
	return $pages;
}

function _urlindex_get_url($page, $urls) {
	global $replace_pairs;
	global $urlusepath;
	$split = explode('/', $page);
	$count = count($split);
	$name = $split[$count-2];
	$url = substr($name, 3);
	$url = str_replace(array('.DEL', 'SLASH', 'AND'), array('', '-', '-'), $url);
	$url = strtr($url, $replace_pairs); # To avoid problems on some servers, this must be before strtolower
	$url = strtolower($url); # This creates crazy characters for some hosters
	# This doesn't work if the server has problems with unicode, next line does the same
	# $url = preg_replace('/[^\w-]/', '', $url);
	$url = preg_replace('/[^A-Za-z0-9-]/', '', $url);
	$url = preg_replace('/-+/', '-', $url);
	if ($urlusepath == 'on') {
		if ($count > 3) {
			$folder = substr($page, 0, strrpos($page, $name)).'01,Home';
			$folder = $urls[$folder];
			$url = $folder.'/'.$url;
		}
	}
	if (in_array($url, $urls) or ($url == '' && in_array('1', $urls))) {
		$i = 2;
		if ($url != '') {
			$before = $url.'-';
		} else {
			$before = '';
		}
		while (in_array($before.$i, $urls)) {
			$i++;
		}
		$url = $before.$i;
	} elseif ($url == '') {
		$url = '1';
	}
	return $url;
}

function generate_urlindex() {
	$pages = _urlindex_get_pages();
	natcasesort($pages);
	$urls = array();
	$urlindex = '';
	foreach($pages as $page) {
		$contents = file_get_contents('../data/pages/'.$page);
		if (preg_match('/%%REDIRECT-(.*)%%/U', $contents, $matches) == 0) {
			$url = _urlindex_get_url($page, $urls);
			$urls[$page] = $url;
			$urlindex .= $url."\t".$page."\n";
		} else {
			$urlindex .= 'REDIRECT:'.$matches[1]."\t".$page."\n";
		}
	}
	$handle = fopen('../data/urlindex.txt', 'w+');
	fwrite($handle, $urlindex."\n");
	fclose($handle);
}
?>
